﻿CREATE PROCEDURE DeleteOrder
  @OrderId int
AS

  -- Don't permit orders less than one year old to be deleted
  DECLARE @DaysOld int =
   (SELECT DATEDIFF(DAY, OrderedOn, SYSDATETIME()) FROM [Order] WHERE OrderId = @OrderId);

  -- Ensure the specified Order ID exists 
  IF @@ROWCOUNT = 0
   THROW 50000, 'The specified order was not found', 1;

  -- Ensure orders less than one year old are never deleted
  IF @DaysOld < 365
   THROW 50000, 'Orders less than one year old cannot be deleted', 1;

  -- Delete the row
  DELETE FROM [Order]
   WHERE OrderId = @OrderId;
