﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Web.Http;
using System.Web.Http.Description;
using WineCloudModel;

namespace WineCloudWeb.Controllers
{
    public class WineController : ApiController
    {
        private WineCloudDbEntities db = new WineCloudDbEntities();

        // GET api/Wine
        public IQueryable<Wine> GetWines()
        {
            return db.Wines;
        }

        // GET api/Wine/5
        [ResponseType(typeof(Wine))]
        public IHttpActionResult GetWine(int id)
        {
            Wine wine = db.Wines.Find(id);
            if (wine == null)
            {
                return NotFound();
            }

            return Ok(wine);
        }

        // PUT api/Wine/5
        public IHttpActionResult PutWine(int id, Wine wine)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            if (id != wine.WineId)
            {
                return BadRequest();
            }

            db.Entry(wine).State = EntityState.Modified;

            try
            {
                db.SaveChanges();
            }
            catch (DbUpdateConcurrencyException)
            {
                if (!WineExists(id))
                {
                    return NotFound();
                }
                else
                {
                    throw;
                }
            }

            return StatusCode(HttpStatusCode.NoContent);
        }

        // POST api/Wine
        [ResponseType(typeof(Wine))]
        public IHttpActionResult PostWine(Wine wine)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            db.Wines.Add(wine);
            db.SaveChanges();

            return CreatedAtRoute("DefaultApi", new { id = wine.WineId }, wine);
        }

        // DELETE api/Wine/5
        [ResponseType(typeof(Wine))]
        public IHttpActionResult DeleteWine(int id)
        {
            Wine wine = db.Wines.Find(id);
            if (wine == null)
            {
                return NotFound();
            }

            db.Wines.Remove(wine);
            db.SaveChanges();

            return Ok(wine);
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }

        private bool WineExists(int id)
        {
            return db.Wines.Count(e => e.WineId == id) > 0;
        }
    }
}